@@ -13,25 +13,23 @@ class Distro(Module):
         usr = kw['usr']
         pub = kw['pub']
 
-        distro = target.distro
-
-        user = distro.user(usr)
+        user = target.user(usr)
 
         path = f'/home/{usr}/.ssh'
         name = f'authorized_keys'
         full = f'{path}/{name}'
 
-        ok = distro.dir(
+        ok = target.dir(
             path, mode='700', user=usr, group=user.group.name
-        ).deploy()
+        )
 
         if not ok:
             return False
 
         target.send(pub, full)
 
-        ok = distro.file(
+        ok = target.file(
             full, mode='600', user=usr, group=user.group.name
-        ).deploy()
+        )
 
         return ok
