@@ -13,7 +13,7 @@ class Distro(Module):
 
     def deploy(self, target, *, user):
 
-        grp = target.groups(user)
+        grp = target.groups.fetch(user)
         grp.add('wheel')
 
         line = f'{user} ALL=(ALL) NOPASSWD: ALL'
